@@ -22,7 +22,7 @@ sets_query_by_event_id = """
 
 """
 
-tournament_query_by_event_id = """
+tournament_query_by_slug = """
     query FindEventId($slug: String!) {
         tournament(slug: $slug) {
             id
@@ -31,6 +31,12 @@ tournament_query_by_event_id = """
                 id
                 name
             }
+            images{
+              id
+              url
+              height
+              width
+            }
         }
     }
 """
