@@ -2,9 +2,11 @@ from .BaseApi import BaseApi
 from .TournamentApi import TournamentApi
 from .EntrantApi import EntrantApi
 from .EventApi import EventApi
+from .VideogameApi import VideogameApi
 
 __all__ = [
     "TournamentApi",
     "EntrantApi",
-    "EventApi"
+    "EventApi",
+    "VideogameApi",
 ]
